@@ -7,6 +7,10 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <iostream>
 #include <sstream>
 #include <stdio.h>
@@ -16,18 +20,33 @@
 #include <librevenge-stream/librevenge-stream.h>
 #include <libcdr/libcdr.h>
 
+#ifndef VERSION
+#define VERSION "UNKNOWN VERSION"
+#endif
+
 namespace
 {
 
 int printUsage()
 {
-  printf("Usage: cdr2xhtml [OPTION] <Corel Draw Document>\n");
+  printf("`cdr2xhtml' converts CorelDRAW documents to SVG.\n");
+  printf("\n");
+  printf("Usage: cdr2xhtml [OPTION] FILE\n");
   printf("\n");
   printf("Options:\n");
-  printf("--help                Shows this help message\n");
+  printf("\t--help                show this help message\n");
+  printf("\t--version             show version information and exit\n");
+  printf("\n");
+  printf("Report bugs to <https://bugs.documentfoundation.org/>.\n");
   return -1;
 }
 
+int printVersion()
+{
+  printf("cdr2xhtml " VERSION "\n");
+  return 0;
+}
+
 } // anonymous namespace
 
 int main(int argc, char *argv[])
@@ -39,7 +58,9 @@ int main(int argc, char *argv[])
 
   for (int i = 1; i < argc; i++)
   {
-    if (!file && strncmp(argv[i], "--", 2))
+    if (!strcmp(argv[i], "--version"))
+      return printVersion();
+    else if (!file && strncmp(argv[i], "--", 2))
       file = argv[i];
     else
       return printUsage();
@@ -49,20 +70,28 @@ int main(int argc, char *argv[])
     return printUsage();
 
   librevenge::RVNGFileStream input(file);
+  librevenge::RVNGStringVector output;
+  librevenge::RVNGSVGDrawingGenerator painter(output, "svg");
 
   if (!libcdr::CDRDocument::isSupported(&input))
   {
-    std::cerr << "ERROR: Unsupported file format!" << std::endl;
+    if (!libcdr::CMXDocument::isSupported(&input))
+    {
+      fprintf(stderr, "ERROR: Unsupported file format (unsupported version) or file is encrypted!\n");
+      return 1;
+    }
+    else if (!libcdr::CMXDocument::parse(&input, &painter))
+    {
+      fprintf(stderr, "ERROR: Parsing of document failed!\n");
+      return 1;
+    }
+  }
+  else if (!libcdr::CDRDocument::parse(&input, &painter))
+  {
+    fprintf(stderr, "ERROR: Parsing of document failed!\n");
     return 1;
   }
 
-  librevenge::RVNGStringVector output;
-  librevenge::RVNGSVGDrawingGenerator generator(output, "svg");
-  if (!libcdr::CDRDocument::parse(&input, &generator))
-  {
-    std::cerr << "ERROR: SVG Generation failed!" << std::endl;
-    return 1;
-  }
   if (output.empty())
   {
     std::cerr << "ERROR: No SVG document generated!" << std::endl;
