@@ -70,20 +70,28 @@ int main(int argc, char *argv[])
     return printUsage();
 
   librevenge::RVNGFileStream input(file);
+  librevenge::RVNGStringVector output;
+  librevenge::RVNGSVGDrawingGenerator painter(output, "svg");
 
   if (!libcdr::CMXDocument::isSupported(&input))
   {
-    std::cerr << "ERROR: Unsupported file format!" << std::endl;
+    if (!libcdr::CDRDocument::isSupported(&input))
+    {
+      fprintf(stderr, "ERROR: Unsupported file format (unsupported version) or file is encrypted!\n");
+      return 1;
+    }
+    else if (!libcdr::CDRDocument::parse(&input, &painter))
+    {
+      fprintf(stderr, "ERROR: Parsing of document failed!\n");
+      return 1;
+    }
+  }
+  else if (!libcdr::CMXDocument::parse(&input, &painter))
+  {
+    fprintf(stderr, "ERROR: Parsing of document failed!\n");
     return 1;
   }
 
-  librevenge::RVNGStringVector output;
-  librevenge::RVNGSVGDrawingGenerator generator(output, "svg");
-  if (!libcdr::CMXDocument::parse(&input, &generator))
-  {
-    std::cerr << "ERROR: SVG Generation failed!" << std::endl;
-    return 1;
-  }
   if (output.empty())
   {
     std::cerr << "ERROR: No SVG document generated!" << std::endl;
