@@ -68,16 +68,23 @@ int main(int argc, char *argv[])
     return printUsage();
 
   librevenge::RVNGFileStream input(file);
-
-  if (!libcdr::CDRDocument::isSupported(&input))
-  {
-    fprintf(stderr, "ERROR: Unsupported file format (unsupported version) or file is encrypted!\n");
-    return 1;
-  }
-
   librevenge::RVNGStringVector pages;
   librevenge::RVNGTextDrawingGenerator painter(pages);
-  if (!libcdr::CDRDocument::parse(&input, &painter))
+
+  if (!libcdr::CMXDocument::isSupported(&input))
+  {
+    if (!libcdr::CDRDocument::isSupported(&input))
+    {
+      fprintf(stderr, "ERROR: Unsupported file format (unsupported version) or file is encrypted!\n");
+      return 1;
+    }
+    else if (!libcdr::CDRDocument::parse(&input, &painter))
+    {
+      fprintf(stderr, "ERROR: Parsing of document failed!\n");
+      return 1;
+    }
+  }
+  else if (!libcdr::CMXDocument::parse(&input, &painter))
   {
     fprintf(stderr, "ERROR: Parsing of document failed!\n");
     return 1;
